==> binutils-2.21-arm-2.tgz: install/doinst.sh <==
( cd usr/arm-slackware-linux-gnueabi/bin ; rm -rf ld )
( cd usr/arm-slackware-linux-gnueabi/bin ; ln -sf /usr/bin/ld ld )
( cd usr/arm-slackware-linux-gnueabi/bin ; rm -rf nm )
( cd usr/arm-slackware-linux-gnueabi/bin ; ln -sf /usr/bin/nm nm )
( cd usr/arm-slackware-linux-gnueabi/bin ; rm -rf objcopy )
( cd usr/arm-slackware-linux-gnueabi/bin ; ln -sf /usr/bin/objcopy objcopy )
( cd usr/arm-slackware-linux-gnueabi/bin ; rm -rf ranlib )
( cd usr/arm-slackware-linux-gnueabi/bin ; ln -sf /usr/bin/ranlib ranlib )
( cd usr/arm-slackware-linux-gnueabi/bin ; rm -rf ar )
( cd usr/arm-slackware-linux-gnueabi/bin ; ln -sf /usr/bin/ar ar )
( cd usr/arm-slackware-linux-gnueabi/bin ; rm -rf ld.gold )
( cd usr/arm-slackware-linux-gnueabi/bin ; ln -sf /usr/bin/ld.gold ld.gold )
( cd usr/arm-slackware-linux-gnueabi/bin ; rm -rf as )
( cd usr/arm-slackware-linux-gnueabi/bin ; ln -sf /usr/bin/as as )
( cd usr/arm-slackware-linux-gnueabi/bin ; rm -rf strip )
( cd usr/arm-slackware-linux-gnueabi/bin ; ln -sf /usr/bin/strip strip )
( cd usr/arm-slackware-linux-gnueabi/bin ; rm -rf objdump )
( cd usr/arm-slackware-linux-gnueabi/bin ; ln -sf /usr/bin/objdump objdump )
( cd usr/arm-slackware-linux-gnueabi/bin ; rm -rf ld.bfd )
( cd usr/arm-slackware-linux-gnueabi/bin ; ln -sf /usr/bin/ld.bfd ld.bfd )
( cd usr/lib ; rm -rf libbfd.so )
( cd usr/lib ; ln -sf libbfd-2.21.so libbfd.so )
( cd usr/lib ; rm -rf libopcodes.so )
( cd usr/lib ; ln -sf libopcodes-2.21.so libopcodes.so )
( cd usr/bin ; rm -rf ld )
( cd usr/bin ; ln -sf ld.bfd ld )

==> binutils-2.21.53.0.2-arm-2.tgz: install/doinst.sh <==
( cd usr/bin ; rm -rf ld )
( cd usr/bin ; ln -sf ld.bfd ld )
( cd usr/lib ; rm -rf libbfd.so )
( cd usr/lib ; ln -sf libbfd-2.21.53.0.2.20110804.so libbfd.so )
( cd usr/lib ; rm -rf libopcodes.so )
( cd usr/lib ; ln -sf libopcodes-2.21.53.0.2.20110804.so libopcodes.so )
( cd usr/arm-slackware-linux-gnueabi/bin ; rm -rf nm )
( cd usr/arm-slackware-linux-gnueabi/bin ; ln -sf /usr/bin/nm nm )
( cd usr/arm-slackware-linux-gnueabi/bin ; rm -rf as )
( cd usr/arm-slackware-linux-gnueabi/bin ; ln -sf /usr/bin/as as )
( cd usr/arm-slackware-linux-gnueabi/bin ; rm -rf ld )
( cd usr/arm-slackware-linux-gnueabi/bin ; ln -sf /usr/bin/ld ld )
( cd usr/arm-slackware-linux-gnueabi/bin ; rm -rf strip )
( cd usr/arm-slackware-linux-gnueabi/bin ; ln -sf /usr/bin/strip strip )
( cd usr/arm-slackware-linux-gnueabi/bin ; rm -rf objcopy )
( cd usr/arm-slackware-linux-gnueabi/bin ; ln -sf /usr/bin/objcopy objcopy )
( cd usr/arm-slackware-linux-gnueabi/bin ; rm -rf ld.gold )
( cd usr/arm-slackware-linux-gnueabi/bin ; ln -sf /usr/bin/ld.gold ld.gold )
( cd usr/arm-slackware-linux-gnueabi/bin ; rm -rf ld.bfd )
( cd usr/arm-slackware-linux-gnueabi/bin ; ln -sf /usr/bin/ld.bfd ld.bfd )
( cd usr/arm-slackware-linux-gnueabi/bin ; rm -rf objdump )
( cd usr/arm-slackware-linux-gnueabi/bin ; ln -sf /usr/bin/objdump objdump )
( cd usr/arm-slackware-linux-gnueabi/bin ; rm -rf ranlib )
( cd usr/arm-slackware-linux-gnueabi/bin ; ln -sf /usr/bin/ranlib ranlib )
( cd usr/arm-slackware-linux-gnueabi/bin ; rm -rf ar )
( cd usr/arm-slackware-linux-gnueabi/bin ; ln -sf /usr/bin/ar ar )
( cd usr/arm-slackware-linux-gnueabi/lib ; rm -rf ldscripts )
( cd usr/arm-slackware-linux-gnueabi/lib ; ln -sf /usr/lib/ldscripts ldscripts )
